pub enum IpCidr {
V4(Ipv4Cidr),
V6(Ipv6Cidr),
}Expand description
Cidr type representing either an IPv4 or an IPv6 network
Variants
Implementations
Sourceimpl IpCidr
impl IpCidr
Sourcepub const fn new(addr: IpAddr, len: u8) -> Result<IpCidr, NetworkParseError>
pub const fn new(addr: IpAddr, len: u8) -> Result<IpCidr, NetworkParseError>
Create new network from address and prefix length. If the network length exceeds the address length or the address is not the first address in the network (“host part not zero”) an error is returned.
Sourcepub const fn new_host(addr: IpAddr) -> IpCidr
pub const fn new_host(addr: IpAddr) -> IpCidr
Create a network containing a single address (network length = address length).
Sourcepub const fn iter(&self) -> InetIterator<IpAddr>
pub const fn iter(&self) -> InetIterator<IpAddr>
Iterate over all addresses in the range. With IPv6 addresses this can produce really long iterations (up to 2128 addresses).
Sourcepub const fn first_address(&self) -> IpAddr
pub const fn first_address(&self) -> IpAddr
first address in the network as plain address
Sourcepub const fn last_address(&self) -> IpAddr
pub const fn last_address(&self) -> IpAddr
last address in the network as plain address
Sourcepub const fn network_length(&self) -> u8
pub const fn network_length(&self) -> u8
length in bits of the shared prefix of the contained addresses
Sourcepub const fn is_host_address(&self) -> bool
pub const fn is_host_address(&self) -> bool
whether network represents a single host address